@@ -22,6 +22,8 @@ def datread(file: str = None, start: int = 0, end: int = None):
                 op = [line.split() for line in lines]
     except FileNotFoundError:
         logger.error(f"File {file} not found.")
+        op = None
+
     return op
 
 
@@ -152,12 +154,15 @@ class PointSet(Package):
             # If Z (depth) information exists, sets the dimensionality to 3
             self.xyz = self.dataframe[["x", "y", "z"]].to_numpy()
             self.dimension = 3
-            logger.info("3D dataset detected.")
+            if self.parent.verbose:
+                logger.info("3D dataset detected.")
             if force_2d:
-                logger.info("3D dataset detected, but 2D will be enforced.")
+                if self.parent.verbose:
+                    logger.info("3D dataset detected, but 2D will be enforced.")
                 self.dataframe["z"] = np.zeros(self.dataframe.shape[0])
         except KeyError:  # Assumes 2D dataset
-            logger.info("2D dataset detected.")
+            if self.parent.verbose:
+                logger.info("2D dataset detected.")
             # Replaces Z dimension by 0's
             self.dataframe.insert(2, "z", np.zeros(self.dataframe.shape[0]))
             self.columns = list(self.dataframe.columns.values)
@@ -178,7 +183,8 @@ class PointSet(Package):
         head = datread(self.file_path, start=2, end=2 + n_features)
         columns_name = [h[0].lower() for h in head]  # Column names (lowered)
         data = datread(self.file_path, start=2 + n_features)  # Raw data
-        logger.info("Data loaded.")
+        if self.parent.verbose:
+            logger.info("Data loaded.")
         return data, project_name, columns_name
 
     def export_01(self, features: list = None):
@@ -197,7 +203,9 @@ class PointSet(Package):
             subframe = self.dataframe[["x", "y", "z", pp]]
             ps_name = jp(self.res_dir, pp)  # Path of binary file
             write_point_set(ps_name, subframe)  # Write binary file
-            if (pp not in self.parent.object_file_names
+            if (
+                pp not in self.parent.object_file_names
             ):  # Adding features name to load them within sgems
                 self.parent.object_file_names.append(pp)
-            logger.info(f"Feature {pp} exported to binary file")
+            if self.parent.verbose:
+                logger.info(f"Feature {pp} exported to binary file")
