@@ -28,13 +28,15 @@ class Plots(Package):
             pass
         try:
             plt.xticks(
-                np.cumsum(self.parent.dis.along_r) + self.parent.dis.xo -
-                self.parent.dis.dx,
+                np.cumsum(self.parent.dis.along_r)
+                + self.parent.dis.xo
+                - self.parent.dis.dx,
                 labels=[],
             )
             plt.yticks(
-                np.cumsum(self.parent.dis.along_c) + self.parent.dis.yo -
-                self.parent.dis.dy,
+                np.cumsum(self.parent.dis.along_c)
+                + self.parent.dis.yo
+                - self.parent.dis.dy,
                 labels=[],
             )
         except Exception as e:
@@ -44,7 +46,7 @@ class Plots(Package):
         plt.grid("blue")
         plt.show()
 
-    def plot_2d(self, res_file=None, save=False):
+    def plot_2d(self, name, res_file=None, save=False):
         """Rudimentary 2D plot"""
         if res_file is None:
             res_file = jp(self.parent.res_dir, "results.grid")
@@ -70,7 +72,7 @@ class Plots(Package):
         )
         plt.colorbar()
         if save:
-            plt.savefig(jp(self.parent.res_dir, "results.png"),
-                        bbox_inches="tight",
-                        dpi=300)
+            plt.savefig(
+                jp(self.parent.res_dir, name), bbox_inches="tight", dpi=300
+            )
         plt.show()
